@@ -174,7 +174,13 @@ sub checkGpgHasDefinedKeyserver {
     my $gnupg2        = $arg_ref->{gnupg2};
 
     if ($gnupg2) {
-        my @output = capturex(qw{gpg-connect-agent --dirmngr keyserver /bye});
+        my @homedir_args = defined $gnupg_homedir
+            ? ('--homedir', $gnupg_homedir)
+            : ();
+        my @output = capturex(
+            'gpg-connect-agent', @homedir_args,
+            qw{--dirmngr keyserver /bye}
+        );
         my $res = pop @output;
         $res eq "OK\n" || croak "Agent replied: $res";
         if (@output) {
