@@ -38,10 +38,16 @@ after 'BUILD' => sub {
     my $self = shift;
     if ($self->gnupg2) {
         unless ($self->already_torified) {
-            system(q{echo 'use-tor:0:1' | gpgconf --change-options dirmngr});
+            my $gnupg_homedir = defined $self->options->homedir()
+                ? $self->options->homedir()
+                : '';
+            system(
+                q{echo 'use-tor:0:1' | } .
+                "GNUPGHOME='$gnupg_homedir' gpgconf --change-options dirmngr"
+            );
             # Passing --runtime to the previous command does not work,
             # so we have to:
-            systemx(qw{gpgconf --reload dirmngr});
+            system("GNUPGHOME='$gnupg_homedir' gpgconf --reload dirmngr");
         }
         $self->call('gpg2');
     }
